@@ -17,7 +17,9 @@ The most commonly used commands are:
     update_basic            update basic data base on raw data
     update_derived          update derived data based on basic and raw data
     update_view             update view data based on basic and derived data
-    data_update             run download_raw, update_basic, update_derived and update_view in turn
+    data_update             run download_raw, update_basic in turn (additionally run update_derived if it's not a trading day)
+    data_update_derived     run update_derived and update_view in turn (should run data_update first)
+    data_update_miscs       run some misc data update jobs (should run data_update first)
     check_fund_list         check fund list to get new funds and delisted funds
     dump_tables_and_dfs     dump all tables and dfs of fund dm to s3
     update_stock_factor     update stock factor and factor return
@@ -45,7 +47,7 @@ class SurfingEntrance(object):
         getattr(self, args.command)()
 
     def _get_yesterday(self):
-        yesterday = datetime.datetime.today() - datetime.timedelta(days = 1)
+        yesterday = datetime.datetime.today() - datetime.timedelta(days=1)
         yesterday_str = datetime.datetime.strftime(yesterday, '%Y%m%d')
         print(f'yesterday: {yesterday_str}')
         return yesterday_str
@@ -175,10 +177,12 @@ class SurfingEntrance(object):
         print('check derived data downloader done')
 
     def data_update(self):
+        from .util.wechat_bot import WechatBot
+        wechat_bot = WechatBot()
+
         print('Start data update')
 
         yesterday = self._get_yesterday()
-
         failed_tasks = {}
         updated_count = {}
 
@@ -190,7 +194,6 @@ class SurfingEntrance(object):
         print('Step 1. Done raw data download')
 
         if 'em_tradedates' in raw_failed_tasks:
-
             print('Step 2. Not tradingday day, basic data to download')
             basic_failed_tasks, basic_updated_count = self.update_basic_not_trading_day(yesterday)
             if len(basic_failed_tasks) > 0:
@@ -209,12 +212,10 @@ class SurfingEntrance(object):
             print(f'Failed tasks:\n{failed_tasks}')
             print(f'Updated count:\n{updated_count}')
 
-            from .util.wechat_bot import WechatBot
-            wechat_bot = WechatBot()
             del failed_tasks['raw'][failed_tasks['raw'].index('em_tradedates')]
             if not failed_tasks['raw']:
                 del failed_tasks['raw']
-            wechat_bot.send_data_update_status(yesterday, failed_tasks, updated_count)
+            wechat_bot.send_data_update_status(yesterday, 'ALL', failed_tasks, updated_count)
             return
 
         print('Step 2. Start update basic')
@@ -223,6 +224,18 @@ class SurfingEntrance(object):
             failed_tasks['basic'] = basic_failed_tasks
         updated_count['basic'] = basic_updated_count
         print('Step 2. Done update basic')
+        wechat_bot.send_data_update_status(yesterday, 'PART-I', failed_tasks, updated_count)
+
+    def data_update_derived(self):
+        from .data.api.raw import RawDataApi
+        yesterday = self._get_yesterday()
+        ret = RawDataApi().get_em_tradedates(yesterday, yesterday)
+        if ret is None or ret.empty:
+            print(f'[data_update_derived] {yesterday} is not a trading day, exit immediately')
+            return
+
+        failed_tasks = {}
+        updated_count = {}
 
         print('Step 3. Start update derived')
         derived_failed_tasks, derived_updated_count = self.update_derived(yesterday)
@@ -247,7 +260,18 @@ class SurfingEntrance(object):
 
         from .util.wechat_bot import WechatBot
         wechat_bot = WechatBot()
-        wechat_bot.send_data_update_status(yesterday, failed_tasks, updated_count)
+        wechat_bot.send_data_update_status(yesterday, 'PART-II', failed_tasks, updated_count)
+
+    def data_update_miscs(self):
+        from .data.api.raw import RawDataApi
+        yesterday = self._get_yesterday()
+        ret = RawDataApi().get_em_tradedates(yesterday, yesterday)
+        if ret is None or ret.empty:
+            print(f'[data_update_miscs] {yesterday} is not a trading day, exit immediately')
+            return
+
+        from .util.wechat_bot import WechatBot
+        wechat_bot = WechatBot()
 
         print('start to check fund list')
         self.check_fund_list(yesterday, wechat_bot)
@@ -393,7 +417,7 @@ class SurfingEntrance(object):
                 elif not last_time_start or time_start.minute > last_time_start.minute or (time_start - last_time_start).seconds >= 60:
                     data_start_time = last_time_start
                     if not data_start_time:
-                        data_start_time = time_start - datetime.timedelta(seconds = 60)
+                        data_start_time = time_start - datetime.timedelta(seconds=60)
                     last_time_start = time_start
                     to_save = not (time_start.hour == 9 and time_start.minute == 30)
                     realtime_index_price_df = em.em_realtime_index(realtime_index_price_processor.index_ids, data_start_time, to_save)
