@@ -734,6 +734,21 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_nav_public <err_msg> {e} from {FOFNavPublic.__tablename__}')
 
+    def delete_fof_nav_public(self, fof_id_to_delete: str, datetime_list: Tuple[str]):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    FOFNavPublic
+                ).filter(
+                    FOFNavPublic.fof_id == fof_id_to_delete,
+                    FOFNavPublic.datetime.in_(datetime_list),
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {FOFNavPublic.__tablename__}')
+                return False
+
     def get_fof_nav_calc(self, manager_id, fof_id_list: Tuple[str] = ()):
         with DerivedDatabaseConnector().managed_session() as session:
             try:
