@@ -861,7 +861,7 @@ class PortfolioDataApi(metaclass=Singleton):
             index_info = BasicDataApi().get_asset_info_real(real_id_list=['hs300','csi500','national_debt']).drop_duplicates(subset='real_id')
             res = []
             for r in index_info.itertuples():
-                res.append([r.asset_id, r.real_name])
+                res.append([r.real_id, r.real_name])
             return res
         
         except Exception as e:
@@ -1044,6 +1044,8 @@ class PortfolioDataApi(metaclass=Singleton):
                 '近一月收益':round(res_status.recent_1m_ret,4),
                 '创建日期':str(res_status.start_date),
                 '当前回撤':round(res_status.recent_drawdown,4),
+                '近一周开始时间':str(res_status.w1_begin_date),
+                '近一周结束时间':str(res_status.w1_end_date),
             }
             fund_weight = data['各基权重'].tail(1).dropna(axis=1).T
             fund_weight.columns = ['weight']
