@@ -158,6 +158,31 @@ class FundDailyCollectionProcessor(object):
             except Exception as e:
                 print('Failed fill get data <err_msg> {}'.format(e))
 
+    def get_fund_nav_start_end_date(self):
+        with BasicDatabaseConnector().managed_session() as mn_session:
+            try:
+                query = mn_session.query(
+                    FundNav.fund_id,
+                    FundNav.datetime,
+                    FundNav.adjusted_net_value)
+                df = pd.read_sql(query.statement, query.session.bind)
+                df = df.pivot_table(index='datetime',values='adjusted_net_value',columns='fund_id')
+                result = []
+                for fund_id in df:
+                    _df = df[[fund_id]].dropna()
+                    dic = {
+                        'fund_id':fund_id,
+                        'price_begin_date':_df.index[0],
+                        'price_end_date':_df.index[-1]
+                    }
+                    result.append(dic)
+                df = pd.DataFrame(result).set_index('fund_id')
+                return df
+                
+            except Exception as e:
+                print('Failed get_fund_nav_start_end_date<err_msg> {}'.format(e))
+
+
     def get_indicator_df(self):
         with BasicDatabaseConnector().managed_session() as quant_session:
             try:
@@ -566,7 +591,8 @@ class FundDailyCollectionProcessor(object):
             style_df = self.get_style_box_detail()
 
             print('处理净值')
-            df = pd.concat([funds, bench, nav, alpha, size, rating, score, new_score, tag_indicator, exchange_status, fund_recommend_extend, fund_manager, style_df], axis=1, sort=False)
+            fund_start_end_date_df = self.get_fund_nav_start_end_date()
+            df = pd.concat([funds, bench, nav, alpha, size, rating, score, new_score, tag_indicator, exchange_status, fund_recommend_extend, fund_manager, style_df, fund_start_end_date_df], axis=1, sort=False)
             df.index.name = 'fund_id'
             print('_'*100)
             print(df)
