@@ -38,6 +38,7 @@ class FOFNAVReader:
         fof_info = BasicDataApi().get_fof_info(self._manager_id)
         assert fof_info is not None and not fof_info.empty, f'get fof info of manager_id {self._manager_id} failed'
         self._hedge_list: Set[str] = set(fof_info[fof_info.asset_type == 'hedge'].fof_id.array)
+        self._product_list: Set[str] = set(fof_info[fof_info.asset_type == 'production'].fof_id.array)
 
         self._fof_id = info['fof_id']
         self._sp_uri = f"{info['server']}:{info['port']}"
@@ -51,16 +52,19 @@ class FOFNAVReader:
         print(f'[read_navs_and_dump_to_db] {err_msg}')
         # self._wechat_bot.send_hedge_fund_nav_update_failed(err_msg)
 
-    def read_navs_and_dump_to_db(self):
-        try:
-            with open(os.path.join(self._read_dir, UID_FILE_NAME), 'rb') as f:
-                uid_last = f.read()
-                if not uid_last:
-                    uid_last = None
-        except FileNotFoundError:
-            uid_last = None
-        except Exception as e:
-            self._notify_error_event(f'read uid file failed (e){e}, use None instead(read all emails) (manager_id){self._manager_id} (fof_id){self._fof_id}')
+    def read_navs_and_dump_to_db(self, is_full: bool = False):
+        if not is_full:
+            try:
+                with open(os.path.join(self._read_dir, UID_FILE_NAME), 'rb') as f:
+                    uid_last = f.read()
+                    if not uid_last:
+                        uid_last = None
+            except FileNotFoundError:
+                uid_last = None
+            except Exception as e:
+                self._notify_error_event(f'read uid file failed (e){e}, use None instead(read all emails) (manager_id){self._manager_id} (fof_id){self._fof_id}')
+                uid_last = None
+        else:
             uid_last = None
 
         try:
@@ -98,7 +102,7 @@ class FOFNAVReader:
                 r1 = self._dump_hedge_to_db(df[df.fof_id.isin(self._hedge_list)])
                 if r1 is not None:
                     df_list.append(r1)
-                r2 = self._dump_fof_to_db(df[~df.fof_id.isin(self._hedge_list)])
+                r2 = self._dump_fof_to_db(df[df.fof_id.isin(self._product_list)])
 
                 if r1 is None and r2 is None:
                     print(f'[read_navs_and_dump_to_db] duplicated data, do not process it (name){name} (manager_id){self._manager_id} (fof_id){self._fof_id}')
@@ -157,6 +161,8 @@ class FOFNAVReader:
                     fof_info_to_set.mdd = float(res_status.mdd) if not pd.isnull(res_status.mdd) else None
                     fof_info_to_set.sharpe = float(res_status.sharpe) if not pd.isnull(res_status.sharpe) else None
                     fof_info_to_set.vol = float(res_status.annualized_vol) if not pd.isnull(res_status.annualized_vol) else None
+                    fof_info_to_set.last_increase_rate = float(res_status.last_increase_rate) if not pd.isnull(res_status.last_increase_rate) else None
+                    fof_info_to_set.last_before_date = nav_of_fof.index.array[-2]
                     db_session.commit()
                     db_session.close()
         return whole_df
@@ -175,7 +181,6 @@ class FOFNAVReader:
         if df.empty:
             return
 
-        # TODO:
         assert df.datetime.nunique() == 1, 'should have single datetime'
         now_df = DerivedDataApi().get_fof_nav(self._manager_id, list(df.fof_id.unique()))
         if now_df is not None and not now_df.empty:
@@ -218,7 +223,6 @@ class FOFNAVReader:
         if df.empty:
             return
 
-        # TODO:
         assert df.datetime.nunique() == 1, 'should have single datetime'
         now_df = DerivedDataApi().get_fof_nav_unconfirmed(self._manager_id, list(df.fof_id.unique()))
         if now_df is not None and not now_df.empty:
