@@ -71,6 +71,9 @@ class ParserRunner(LogCollector):
         parsers_manager: Optional[pd.DataFrame] = BasicDataApi().get_email_parser_exec(manager_id)
         assert parsers_manager is not None and not parsers_manager.empty, f'get email parsers exec info of {manager_id} failed (parser_type){parser_type}'
 
+        if parsers_manager.shape[0] > 1:
+            parsers_manager = parsers_manager[parsers_manager.manager_id.notna()]
+
         priority_info = json.loads(parsers_manager.p_priority_info.array[0])
         assert str(parser_type) in priority_info, f'no {parser_type} exec info of {manager_id}'
         parsers_list_with_priority: List[str] = priority_info[str(parser_type)]
