@@ -48,35 +48,39 @@ class ResearchNAVReader:
             if '业绩走势' in one.name:
                 continue
             try:
-                try:
-                    normal_replace_dict = {
-                        '・': '·',
-                    }
-                    p_name = one.name
-                    for k, v in normal_replace_dict.items():
-                        p_name = p_name.replace(k, v)
-                    print(f'[_read_for_NAVData] (name in tar){one.name}')
-                except UnicodeEncodeError:
-                    replace_dict = {
-                        '\udc9bK': '汯',
-                        '\udcacB': '珺',
-                        '\udcd4Z': '訸',
-                        '\udcb6G': '禛',
-                        '\udc95D': '旸',
-                        '\udcf1I': '馡',
-                        '\udca9q': '﹒',
-                    }
-                    p_name = one.name
-                    for k, v in replace_dict.items():
-                        p_name = p_name.replace(k, v)
-                    print(f'[_read_for_NAVData] (name in tar (fixed)){p_name}')
-                p_name = p_name.split('.')[0]
+                # try:
+                #     normal_replace_dict = {
+                #         '・': '·',
+                #     }
+                #     p_name = one.name
+                #     for k, v in normal_replace_dict.items():
+                #         p_name = p_name.replace(k, v)
+                #     print(f'[_read_for_NAVData] (name in tar){one.name}')
+                # except UnicodeEncodeError:
+                #     replace_dict = {
+                #         '\udc9bK': '汯',
+                #         '\udcacB': '珺',
+                #         '\udcd4Z': '訸',
+                #         '\udcb6G': '禛',
+                #         '\udc95D': '旸',
+                #         '\udcf1I': '馡',
+                #         '\udca9q': '﹒',
+                #     }
+                #     p_name = one.name
+                #     for k, v in replace_dict.items():
+                #         p_name = p_name.replace(k, v)
+                #     print(f'[_read_for_NAVData] (name in tar (fixed)){p_name}')
+                if one.name.startswith('./'):
+                    fund_id = one.name[len('./'):].split('.')[0]
+                else:
+                    fund_id = one.name.split('.')[0]
+                print(f'[_read_for_NAVData] (name in tar){one.name} (fund_id){fund_id}')
                 df = pd.read_excel(tar.extractfile(one), na_values=['--'])
                 df = df.rename(columns={'日期': 'datetime', '净值(分红再投)': 'nav'})
                 df = df[['datetime', 'nav']]
-                hf_fund_info = RawDataApi().get_hf_fund_info()
-                hf_fund_info = hf_fund_info[hf_fund_info.desc_name == p_name]
-                fund_id = hf_fund_info.fund_id.array[0]
+                # hf_fund_info = RawDataApi().get_hf_fund_info()
+                # hf_fund_info = hf_fund_info[hf_fund_info.desc_name == p_name]
+                # fund_id = hf_fund_info.fund_id.array[0]
                 df['fund_id'] = fund_id
                 df['datetime'] = pd.to_datetime(df.datetime, infer_datetime_format=True).dt.date
                 hf_fund_nav = RawDataApi().get_hf_fund_nav(fund_ids=[fund_id])
@@ -88,15 +92,19 @@ class ResearchNAVReader:
                 else:
                     df_fitted = df
                 print(f'to hf_fund_nav {df_fitted}')
-                # TODO: 最好原子提交下边两步
-                RawDataApi().delete_hf_fund_nav(fund_id_to_delete=fund_id, datetime_list=df_fitted.datetime.to_list())
-                # 更新到db
-                df_fitted.to_sql(HFFundNav.__table__.name, RawDatabaseConnector().get_engine(), index=False, if_exists='append')
+                if not df_fitted.empty:
+                    # TODO: 最好原子提交下边两步
+                    RawDataApi().delete_hf_fund_nav(fund_id_to_delete=fund_id, datetime_list=df_fitted.datetime.to_list())
+                    # 更新到db
+                    df_fitted.to_sql(HFFundNav.__table__.name, RawDatabaseConnector().get_engine(), index=False, if_exists='append')
 
                 # 再向 FOFNavPublic 更新一份
                 df = df.rename(columns={'fund_id': 'fof_id', 'nav': 'adjusted_nav'})
-                df['nav'] = np.nan
-                df['acc_net_value'] = np.nan
+                df = df[df.adjusted_nav.notna()]
+                if df.empty:
+                    continue
+                df['nav'] = df.adjusted_nav
+                df['acc_net_value'] = df.adjusted_nav
                 fof_nav_public = DerivedDataApi().get_fof_nav_public(fof_id_list=[fund_id])
                 if fof_nav_public is not None:
                     fof_nav_public = fof_nav_public.drop(columns=['volume', 'mv', 'ret', 'create_time', 'update_time', 'is_deleted'])
@@ -105,14 +113,15 @@ class ResearchNAVReader:
                     df = df.merge(fof_nav_public, how='left', indicator=True, validate='one_to_one')
                     df = df[df._merge == 'left_only'].drop(columns=['_merge'])
                 print(f'to fof_nav_public {df}')
-                # TODO: 最好原子提交下边两步
-                DerivedDataApi().delete_fof_nav_public(fof_id_to_delete=fund_id, datetime_list=df.datetime.to_list())
-                # 更新到db
-                df.to_sql(FOFNavPublic.__table__.name, DerivedDatabaseConnector().get_engine(), index=False, if_exists='append')
-                update_info[p_name] = df.shape[0]
+                if not df.empty:
+                    # TODO: 最好原子提交下边两步
+                    DerivedDataApi().delete_fof_nav_public(fof_id_to_delete=fund_id, datetime_list=df.datetime.to_list())
+                    # 更新到db
+                    df.to_sql(FOFNavPublic.__table__.name, DerivedDatabaseConnector().get_engine(), index=False, if_exists='append')
+                    update_info[fund_id] = df.shape[0]
 
                 fof_nav_public = DerivedDataApi().get_fof_nav_public(fof_id_list=[fund_id])
-                if fof_nav_public is not None:
+                if fof_nav_public is not None and not fof_nav_public.empty:
                     fof_nav_public = fof_nav_public.set_index('datetime')['adjusted_nav']
                     res_status = Calculator.get_stat_result(fof_nav_public.index, fof_nav_public.array)
                     Session = sessionmaker(BasicDatabaseConnector().get_engine())
@@ -120,7 +129,7 @@ class ResearchNAVReader:
                     # '1' 表示公有的 FOFInfo
                     fof_info_to_set = db_session.query(FOFInfo).filter(FOFInfo.manager_id == '1', FOFInfo.fof_id == fund_id).one_or_none()
                     fof_info_to_set.net_asset_value = float(res_status.last_unit_nav) if not pd.isnull(res_status.last_unit_nav) else None
-                    fof_info_to_set.adjusted_net_value = float(fof_nav_public.array[-1]) if not pd.isnull(fof_nav_public.arraay[-1]) else None
+                    fof_info_to_set.adjusted_net_value = float(fof_nav_public.array[-1]) if not pd.isnull(fof_nav_public.array[-1]) else None
                     fof_info_to_set.latest_cal_date = res_status.end_date
                     fof_info_to_set.ret_year_to_now = float(res_status.recent_year_ret) if not pd.isnull(res_status.recent_year_ret) else None
                     fof_info_to_set.ret_total = float(res_status.cumu_ret) if not pd.isnull(res_status.cumu_ret) else None
@@ -128,6 +137,7 @@ class ResearchNAVReader:
                     fof_info_to_set.mdd = float(res_status.mdd) if not pd.isnull(res_status.mdd) else None
                     fof_info_to_set.sharpe = float(res_status.sharpe) if not pd.isnull(res_status.sharpe) else None
                     fof_info_to_set.vol = float(res_status.annualized_vol) if not pd.isnull(res_status.annualized_vol) else None
+                    fof_info_to_set.has_nav = True
                     db_session.commit()
                     db_session.close()
             except Exception as e:
@@ -173,11 +183,12 @@ class ResearchNAVReader:
                 df = df.merge(hf_index_price, how='left', indicator=True, validate='one_to_one')
                 df = df[df._merge == 'left_only'].drop(columns=['_merge'])
             print(df)
-            # TODO: 最好原子提交下边两步
-            RawDataApi().delete_hf_index_price(index_id, df.index_date.to_list())
-            # 更新到db
-            df.to_sql(HFIndexPrice.__table__.name, RawDatabaseConnector().get_engine(), index=False, if_exists='append')
-            update_info[key_name] = df.shape[0]
+            if not df.empty:
+                # TODO: 最好原子提交下边两步
+                RawDataApi().delete_hf_index_price(index_id, df.index_date.to_list())
+                # 更新到db
+                df.to_sql(HFIndexPrice.__table__.name, RawDatabaseConnector().get_engine(), index=False, if_exists='append')
+                update_info[key_name] = df.shape[0]
         tar.close()
         return update_info
 
@@ -216,11 +227,11 @@ class ResearchNAVReader:
                     ret = ordd.hf_fund_nav_miss()
                     assert not ret, 'update table of hf fund nav miss failed!!'
 
-                    self._wechat_bot.send_research_data_update('净值', update_info)
+                    # self._wechat_bot.send_research_data_update('净值', update_info)
                 elif '指数数据' in name:
                     update_info = ResearchNAVReader._read_for_IndexData(file_path)
 
-                    self._wechat_bot.send_research_data_update('指数', update_info)
+                    # self._wechat_bot.send_research_data_update('指数', update_info)
                 else:
                     raise NotImplementedError('unknown research nav file from attachment')
             except Exception as e:
