@@ -57,6 +57,8 @@ class FundDailyCollection(Base):
     change_rate = Column(DOUBLE(asdecimal=False))  # 日收益率
     found_date = Column(CHAR(20))  # 成立日期
     end_date = Column(CHAR(20))  # 关闭日期
+    price_begin_date = Column(DATE)  # 净值开始时间
+    price_end_date = Column(DATE)  # 净值开始时间
 
     # basic.FundRet
     annualized_returns = Column(DOUBLE(asdecimal=False))  # 成立以来年化收益率
@@ -197,6 +199,8 @@ class FundDailyCollection(Base):
             'otc_lp_limit': '场外暂停大额申购上限',
             'otc_lp_limit_jg': '场外暂停大额申购上限(机构)',
             'otc_lp_limit_gr': '场外暂停大额申购上限(个人)',
+            'price_begin_date':'净值开始时间',
+            'price_end_date':'净值结束时间',
 
             'adjusted_net_value': '复权净值',
             'unit_net_value': '净值',
@@ -338,6 +342,7 @@ class IndexDailyCollection(Base):
     pb_pct = Column(DOUBLE(asdecimal=False))  # PB百分位
     ps_pct = Column(DOUBLE(asdecimal=False))  # PS百分位
     val_score = Column(DOUBLE(asdecimal=False))  # 估值评分
+    liqmv = Column(DOUBLE(asdecimal=False))  # 流通市值
 
     # calc based on derived.IndexValuationLongTerm pe_ttm pb_mrq
     pe_0_percentile = Column(DOUBLE(asdecimal=False))  # pe0分位
@@ -385,6 +390,8 @@ class IndexDailyCollection(Base):
     total_turnover = Column(DOUBLE(asdecimal=False))  # 成交额
     ret = Column(DOUBLE(asdecimal=False))  # 收益率
     yest_close = Column(DOUBLE(asdecimal=False))  # 前收盘价
+    price_begin_date = Column(DATE)  # 净值开始时间
+    price_end_date = Column(DATE)  # 净值结束时间
 
     # basic.IndexInfo
     order_book_id = Column(CHAR(20))  # 米筐ID
@@ -434,6 +441,7 @@ class IndexDailyCollection(Base):
             'ps_pct': 'PS百分位',
             'val_score': '估值评分',
             'alpha_datetime': 'alpha日期',
+            'liqmv': '流通市值',
 
             'pe_0_percentile': 'pe0分位',
             'pe_30_percentile': 'pe30分位',
@@ -453,6 +461,8 @@ class IndexDailyCollection(Base):
             'total_turnover': '成交额',
             'ret': '收益率',
             'yest_close': '前收盘价',
+            'price_begin_date':'净值开始时间',
+            'price_end_date':'净值结束时间',
 
             'order_book_id': '指数代码',
             'industry_tag': '行业标签',
@@ -743,4 +753,25 @@ class FundManagerDailyCollection(Base):
             'trading_days':'从业天数',
             'best_fund':'代表作品',
             'company_id':'基金公司',
-        }
\ No newline at end of file
+        }
+
+class HFFundDailyCollection(Base):
+    """基金信息日度收集"""
+
+    __tablename__ = 'hf_fund_daily_collection'
+
+    fund_id = Column(CHAR(20), primary_key=True)  # 基金ID
+    begin_date = Column(CHAR(20), primary_key=True)  # 时间
+    stg_type = Column(CHAR(20))  # 基金代码
+    desc_name = Column(CHAR(40)) # 基金名
+    agency_id = Column(CHAR(10)) # 机构id
+    agency_name = Column(CHAR(20)) # 机构名
+    manager_name = Column(CHAR(20)) # 基金经理名
+    source = Column(CHAR(20)) # 来源
+    nav_source = Column(CHAR(10)) # 净值来源
+
+    annual_ret = Column(DOUBLE(asdecimal=False))  # 成立以来年化收益率
+    annual_vol = Column(DOUBLE(asdecimal=False))  # 成立以来年化波动率
+    sharpe_ratio = Column(DOUBLE(asdecimal=False))  # 成立以来夏普比率
+    price_begin_date = Column(DATE)  # 净值开始时间
+    price_end_date = Column(DATE)  # 净值开始时间
\ No newline at end of file
