@@ -69,6 +69,7 @@ class MailAttachmentRetriever:
                     # criterion = f'(TO "fof@puyuan.tech" UID {last_uid}:*)'
                     criterion = f'(UID {last_uid}:*)'
                     print(criterion)
+                dummy_count = 0
                 typ, data = M.uid('search', None, criterion)
                 for uid in data[0].split():
                     # 上边的criterion不太好用 这里还是需要再过滤一下
@@ -90,17 +91,16 @@ class MailAttachmentRetriever:
                                     real_name = email.header.decode_header(filename)[0][0]
                                     if isinstance(real_name, bytes):
                                         real_name = real_name.decode(email.header.decode_header(filename)[0][1])
+                                    dummy_count += 1
                                     for one in self._file_suffixes:
                                         if real_name.endswith(one):
                                             # pandas可以直接读，但pd.read_excel()里传的参数可能是不一样的，所以这里还是先将内容写到文件里
-                                            # TODO: need to remove this
-                                            if real_name == '产品净值情况.xlsx':
-                                                real_name = f'产品净值情况_{uid}.xlsx'
+                                            real_name = f'c{dummy_count}_{real_name}'
                                             file_path = os.path.join(self._dump_dir, real_name)
                                             with open(file_path, 'wb') as f:
                                                 f.write(part.get_payload(decode=True))
                                             df_list[real_name] = (uid, os.path.abspath(file_path))
-                                            print(f'file {real_name} on {df_list[real_name]} done (uid){uid}')
+                                            print(f'file {real_name} on {df_list[real_name]} done (uid){uid} (dummy_count){dummy_count}')
                                             is_done = True
                                             break
                     if not is_done:
