@@ -57,9 +57,9 @@ class WechatBot(object):
                 print(e)
                 traceback.print_exc()
 
-    def send_data_update_status(self, dt, failed_tasks, updated_count):
+    def send_data_update_status(self, dt, tag, failed_tasks, updated_count):
         # Send markdown content
-        markdown_content = f'{dt} 已完成数据更新，'
+        markdown_content = f'{dt} {tag}已完成数据更新，'
         if len(failed_tasks) == 0:
             markdown_content += '所有数据更新成功'
         else:
